:orphan:

kibitzr.fetcher.browser package
===============================

Submodules
----------

kibitzr.fetcher.browser.fetcher module
--------------------------------------

.. automodule:: kibitzr.fetcher.browser.fetcher
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.fetcher.browser.launcher module
---------------------------------------

.. automodule:: kibitzr.fetcher.browser.launcher
    :members:
    :undoc-members:
    :show-inheritance:

kibitzr.fetcher.browser.trigger module
--------------------------------------

.. automodule:: kibitzr.fetcher.browser.trigger
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: kibitzr.fetcher.browser
    :members:
    :undoc-members:
    :show-inheritance:
